import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import javax.swing.JPanel;

// -------------------------------------------------------------------------
/**
 * Represents the primary drawing panel for the RubberLines program.
 *
 * @author John Lewis
 * @version 2010.02.08
 */
public class RubberLinesPanel
    extends JPanel
{
    // ~ Instance/static variables .............................................

    private Point point1 = null;
    private Point point2 = null;


    // ~ Constructors ..........................................................

    // ----------------------------------------------------------
    /**
     * Constructor: Sets up this panel to listen for mouse events.
     */
    public RubberLinesPanel()
    {
        LineListener listener = new LineListener();
        addMouseListener(listener);
        addMouseMotionListener(listener);

        setBackground(Color.black);
        setPreferredSize(new Dimension(400, 200));
    }


    // ~ Public methods ........................................................

    // ----------------------------------------------------------
    /**
     * Draws the current line from the intial mouse-pressed point to the current
     * position of the mouse.
     */
    @Override
    public void paintComponent(Graphics page)
    {
        super.paintComponent(page);

        page.setColor(Color.yellow);
        if (point1 != null && point2 != null)
        {
            page.drawLine(point1.x, point1.y, point2.x, point2.y);
        }
    }

    public Point getStartPoint() { return point1; }
    public Point getEndPoint() { return point2; }

    //~ Private methods/declarations ..........................................

    // ----------------------------------------------------------
    /**
     * Represents the listener for all mouse events.
     */
    private class LineListener
        implements MouseListener, MouseMotionListener
    {
        // ----------------------------------------------------------
        /**
         * Captures the initial position at which the mouse button is
         * pressed.
         * @param event The event to be handled
         */
        public void mousePressed(MouseEvent event)
        {
            point1 = event.getPoint();
        }


        // ----------------------------------------------------------
        /**
         * Gets the current position of the mouse as it is dragged and
         * redraws the line to create the rubberband effect.
         * @param event The event to be handled
         */
        public void mouseDragged(MouseEvent event)
        {
            point2 = event.getPoint();
            repaint();
        }


        // ----------------------------------------------------------
        /**
         * Unused event handler, provided for interface compliance.
         * @param event The mouse event
         */
        public void mouseClicked(MouseEvent event)
        {
            // not used
        }


        // ----------------------------------------------------------
        /**
         * Unused event handler, provided for interface compliance.
         * @param event The mouse event
         */
        public void mouseReleased(MouseEvent event)
        {
            // not used
        }


        // ----------------------------------------------------------
        /**
         * Unused event handler, provided for interface compliance.
         * @param event The mouse event
         */
        public void mouseEntered(MouseEvent event)
        {
            // not used
        }


        // ----------------------------------------------------------
        /**
         * Unused event handler, provided for interface compliance.
         * @param event The mouse event
         */
        public void mouseExited(MouseEvent event)
        {
            // not used
        }


        public void mouseMoved(MouseEvent event)
        // ----------------------------------------------------------
        /**
         * Unused event handler, provided for interface compliance.
         * @param event The mouse event
         */
        {
            // not used
        }
    }
}
